@@ -74,13 +74,24 @@ estimatePointPrevalence <- function(cdm,
                                     includeOverallStrata = TRUE,
                                     minCellCount = 5,
                                     returnParticipants = FALSE) {
+
+
+  if (isTRUE(returnParticipants)) {
+    lifecycle::deprecate_warn(
+      when = "0.8.0",
+      what = "IncidencePrevalence::estimatePointPrevalence(returnParticipants)",
+      details = "The returnParticipants argument will be removed in the next release"
+    )
+  }
+
+
   errorMessage <- checkmate::makeAssertCollection()
   checkmate::assertTRUE(
     all(tolower(interval) %in%
-      c(
-        "weeks", "months",
-        "quarters", "years"
-      )),
+          c(
+            "weeks", "months",
+            "quarters", "years"
+          )),
     add = errorMessage
   )
   checkmate::reportAssertions(collection = errorMessage)
@@ -171,6 +182,15 @@ estimatePeriodPrevalence <- function(cdm,
                                      includeOverallStrata = TRUE,
                                      minCellCount = 5,
                                      returnParticipants = FALSE) {
+
+  if (isTRUE(returnParticipants)) {
+    lifecycle::deprecate_warn(
+      when = "0.8.0",
+      what = "IncidencePrevalence::estimatePeriodPrevalence(returnParticipants)",
+      details = "The returnParticipants argument will be removed in the next release"
+    )
+  }
+
   estimatePrevalence(
     cdm = cdm,
     denominatorTable = denominatorTable,
@@ -203,6 +223,9 @@ estimatePrevalence <- function(cdm,
                                includeOverallStrata = TRUE,
                                minCellCount = 5,
                                returnParticipants = FALSE) {
+
+  summarisedResult <- FALSE
+
   startCollect <- Sys.time()
 
   # help to avoid formatting errors
@@ -228,29 +251,29 @@ estimatePrevalence <- function(cdm,
 
   # if not given, use all denominator and outcome cohorts
   if (is.null(denominatorCohortId)) {
-    denominatorCohortId <- CDMConnector::cohortCount(
+    denominatorCohortId <- omopgenerics::cohortCount(
       cdm[[denominatorTable]]) %>%
       dplyr::filter(.data$number_records > 0) %>%
       dplyr::pull("cohort_definition_id")
   }
   if (is.null(outcomeCohortId)) {
-    outcomeCohortId <- CDMConnector::cohortCount(cdm[[outcomeTable]]) %>%
+    outcomeCohortId <- omopgenerics::cohortCount(cdm[[outcomeTable]]) %>%
       dplyr::pull("cohort_definition_id")
   }
 
   ## add outcome from attribute
   if (is.null(outcomeCohortId)) {
-    outcomeCohortId <- CDMConnector::cohortCount(cdm[[outcomeTable]]) %>% dplyr::pull("cohort_definition_id")
+    outcomeCohortId <- omopgenerics::cohortCount(cdm[[outcomeTable]]) %>% dplyr::pull("cohort_definition_id")
   }
 
-  outcomeRef <- CDMConnector::settings(cdm[[outcomeTable]]) %>%
+  outcomeRef <- omopgenerics::settings(cdm[[outcomeTable]]) %>%
     dplyr::filter(.env$outcomeCohortId %in% .data$cohort_definition_id) %>%
     dplyr::collect("cohort_definition_id", "cohort_name") %>%
     dplyr::rename("outcome_cohort_id" = "cohort_definition_id",
                   "outcome_cohort_name" = "cohort_name")
 
   if(nrow(outcomeRef) == 0){
-    cli::cli_abort(c("Specified outcome IDs not found in the cohort set of
+    cli::cli_abort(message = c("Specified outcome IDs not found in the cohort set of
                     {paste0('cdm$', outcomeTable)}",
                      "i" = "Run CDMConnector::cohort_set({paste0('cdm$', outcomeTable)})
                    to check which IDs exist"))
@@ -348,15 +371,15 @@ estimatePrevalence <- function(cdm,
   # analysis settings
   analysisSettings <- prsList[names(prsList) == "analysis_settings"]
   analysisSettings <- dplyr::bind_rows(analysisSettings,
-    .id = NULL
+                                       .id = NULL
   )
 
   analysisSettings <- analysisSettings %>%
     dplyr::left_join(
-      CDMConnector::settings(cdm[[denominatorTable]]) %>%
+      omopgenerics::settings(cdm[[denominatorTable]]) %>%
         dplyr::rename("cohort_id" = "cohort_definition_id") %>%
         dplyr::rename_with(
-          .cols = tidyselect::everything(),
+          .cols = dplyr::everything(),
           function(x) {
             paste0("denominator_", x)
           }
@@ -369,10 +392,10 @@ estimatePrevalence <- function(cdm,
   # the denominator cohort used
   for (i in seq_along(studySpecs)) {
     prsList[names(prsList) == "attrition"][[i]] <- dplyr::bind_rows(
-      CDMConnector::attrition(cdm[[denominatorTable]]) %>%
+      omopgenerics::attrition(cdm[[denominatorTable]]) %>%
         dplyr::rename("denominator_cohort_id" = "cohort_definition_id") %>%
         dplyr::filter(.data$denominator_cohort_id ==
-          studySpecs[[i]]$denominatorCohortId) %>%
+                        studySpecs[[i]]$denominatorCohortId) %>%
         dplyr::mutate(analysis_id = studySpecs[[i]]$analysis_id) %>%
         dplyr::mutate(dplyr::across(dplyr::where(is.numeric), as.integer)),
       prsList[names(prsList) == "attrition"][[i]] %>%
@@ -402,13 +425,13 @@ estimatePrevalence <- function(cdm,
 
   CDMConnector::dropTable(
     cdm = cdm,
-    name = tidyselect::starts_with(paste0(tablePrefix, "_analysis_"))
+    name = dplyr::starts_with(paste0(tablePrefix, "_analysis_"))
   )
 
   # prevalence estimates
   prs <- prsList[names(prsList) == "pr"]
   prs <- dplyr::bind_rows(prs,
-    .id = NULL
+                          .id = NULL
   )
 
   # get confidence intervals
@@ -425,25 +448,23 @@ estimatePrevalence <- function(cdm,
       dplyr::relocate("prevalence_95CI_lower", .after = "prevalence") %>%
       dplyr::relocate("prevalence_95CI_upper", .after = "prevalence_95CI_lower")
 
-    # obscure counts
-    prs <- obscureCounts(prs,
-      minCellCount = minCellCount,
-      substitute = NA
-    )
+    if (!summarisedResult) {
+      # obscure counts
+      prs <- obscureCounts(prs,
+                           minCellCount = minCellCount,
+                           substitute = NA
+      )
+    }
   }
 
   # attrition summary
   attrition <- prsList[names(prsList) == "attrition"]
   # to tibble
-  attrition <- dplyr::bind_rows(attrition,
-    .id = NULL
-  ) %>%
+  attrition <- dplyr::bind_rows(attrition,.id = NULL) %>%
     dplyr::select(-"denominator_cohort_id") %>%
     dplyr::relocate("analysis_id")
   # obscure counts
-  attrition <- obscureAttrition(attrition,
-                       minCellCount = minCellCount
-  )
+  attrition <- obscureAttrition(attrition, minCellCount = minCellCount)
 
   analysisSettings <- analysisSettings %>%
     dplyr::left_join(outcomeRef, by = "outcome_cohort_id") %>%
@@ -453,21 +474,94 @@ estimatePrevalence <- function(cdm,
                     .after = "analysis_min_cell_count") %>%
     dplyr::mutate(cdm_name = attr(cdm, "cdm_name"))
 
-  # add settings to estimates and attrition
-  if (nrow(prs) >= 1) {
-    prs <- prs %>%
+
+  if (!summarisedResult) {
+    # add settings to estimates and attrition
+    if (nrow(prs) >= 1) {
+      prs <- prs %>%
+        dplyr::left_join(analysisSettings, by = "analysis_id")
+    }
+    attrition <- attrition %>%
       dplyr::left_join(analysisSettings, by = "analysis_id")
+    attr(prs, "settings") <- analysisSettings
+
+  } else {
+    # summarised result
+    ## settings
+    analysisSettings <- analysisSettings |>
+      dplyr::mutate(
+        result_id = as.integer(.data$analysis_id),
+        result_type = paste0(.env$type, "_prevalence"),
+        package_name = "IncidencePrevalence",
+        package_version = as.character(utils::packageVersion("IncidencePrevalence"))
+      ) |>
+      dplyr::select(!dplyr::ends_with("_cohort_id")) |>
+      dplyr::select(!dplyr::ends_with("_cohort_definition_id")) |>
+      dplyr::select(c(
+        "result_id", "result_type", "package_name", "package_version",
+        "analysis_type", "analysis_interval",
+        "analysis_complete_database_intervals", "analysis_full_contribution"),
+        dplyr::starts_with("denominator_"), dplyr::starts_with("outcome_")
+      )
+    ## result
+    if (!"strata_name" %in% colnames(prs)) {
+      prs <- prs |>
+        visOmopResults::uniteStrata()
+    }
+    prs <- prs |>
+      dplyr::distinct() |>
+      dplyr::mutate("analysis_id" = as.integer(.data$analysis_id)) |>
+      dplyr::rename(
+        "result_id" = "analysis_id",
+        "outcome_count" = "n_cases",
+        "denominator_count" = "n_population"
+      ) |>
+      dplyr::left_join(
+        analysisSettings |>
+          dplyr::select(c(
+            "result_id", "denominator_cohort_name", "outcome_cohort_name"
+          )),
+        by = "result_id"
+      ) |>
+      visOmopResults::uniteGroup("denominator_cohort_name") |>
+      visOmopResults::uniteAdditional(cols = c("prevalence_start_date", "prevalence_end_date")) |>
+      visOmopResults::uniteNameLevel(
+        cols = "outcome_cohort_name",
+        name = "variable_name",
+        level = "variable_level"
+      ) |>
+      tidyr::pivot_longer(
+        cols = c("denominator_count", "outcome_count", "prevalence",
+                 "prevalence_95CI_lower", "prevalence_95CI_upper"),
+        names_to = "estimate_name",
+        values_to = "estimate_value"
+      ) |>
+      dplyr::mutate(
+        "estimate_value" = as.character(.data$estimate_value),
+        "estimate_type" = dplyr::if_else(
+          grepl("count", .data$estimate_name), "integer", "numeric"
+        ),
+        "cdm_name" = attr(cdm, "cdm_name"),
+        "strata_name" = dplyr::if_else(.data$strata_name == "Overall", "overall", gsub(" and ", " &&& ", .data$strata_name)),
+        "strata_level" = dplyr::if_else(.data$strata_level == "Overall", "overall", gsub(" and ", " &&& ", .data$strata_level))
+      )
+
+    prs <- omopgenerics::newSummarisedResult(prs, settings = analysisSettings) |>
+      omopgenerics::suppress(minCellCount = minCellCount)
+
+    ## attrition
+    attrition <- attrition |>
+      dplyr::mutate("result_id" = as.integer(.data$analysis_id)) |>
+      dplyr::select(!"analysis_id") |>
+      dplyr::relocate("result_id")
+
   }
-  attrition <- attrition %>%
-    dplyr::left_join(analysisSettings, by = "analysis_id")
 
   # return results as an IncidencePrevalenceResult class
-  attr(prs, "settings") <- analysisSettings
   attr(prs, "attrition") <- attrition
   if (returnParticipants == TRUE) {
     attr(prs, "participants") <- cdm[[nm]]
   }
-
   class(prs) <- c("IncidencePrevalenceResult", "PrevalenceResult", class(prs))
 
   dur <- abs(as.numeric(Sys.time() - startCollect, units = "secs"))
