@@ -19,14 +19,14 @@ test_that("mock db: check output format", {
     "end_date",
     "days_prior_observation"
   ) %in%
-    names(CDMConnector::settings(cdm$denominator))))
+    names(omopgenerics::settings(cdm$denominator))))
 
   expect_true(all(c(
     "cohort_definition_id",
     "number_records",
     "number_subjects"
   ) %in%
-    names(CDMConnector::cohortCount(cdm$denominator))))
+    names(omopgenerics::cohortCount(cdm$denominator))))
 
   # variable names
   expect_true(all(c(
@@ -40,11 +40,11 @@ test_that("mock db: check output format", {
     "reason_id", "reason",
     "excluded_records", "excluded_subjects"
   ) %in%
-    names(CDMConnector::attrition(cdm$denominator))))
+    names(omopgenerics::attrition(cdm$denominator))))
 
-  expect_true(tibble::is_tibble(CDMConnector::attrition(cdm$denominator)))
-  expect_true(CDMConnector::cohortCount(cdm$denominator)$number_records == 1)
-  expect_true(CDMConnector::cohortCount(cdm$denominator) %>%
+  expect_true(is.data.frame(omopgenerics::attrition(cdm$denominator)))
+  expect_true(omopgenerics::cohortCount(cdm$denominator)$number_records == 1)
+  expect_true(omopgenerics::cohortCount(cdm$denominator) %>%
     dplyr::filter(cohort_definition_id == 1) %>%
     dplyr::pull("number_records") == 1)
 
@@ -52,14 +52,14 @@ test_that("mock db: check output format", {
 })
 
 test_that("mock db: checks on working example", {
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 01,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = "1",
     person_id = "1",
     observation_period_start_date = as.Date("2010-01-01"),
@@ -77,19 +77,19 @@ test_that("mock db: checks on working example", {
     sex = c("Female", "Male")
   )
 
-  femaleCohortIds <- CDMConnector::settings(cdm$denominator) %>%
+  femaleCohortIds <- omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Female") %>%
     dplyr::pull("cohort_definition_id")
-  maleCohortIds <- CDMConnector::settings(cdm$denominator) %>%
+  maleCohortIds <- omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Male") %>%
     dplyr::pull("cohort_definition_id")
 
   # Female cohorts should be empty
-  expect_true(CDMConnector::cohortCount(cdm$denominator) %>%
+  expect_true(omopgenerics::cohortCount(cdm$denominator) %>%
     dplyr::filter(cohort_definition_id %in% femaleCohortIds) %>%
     dplyr::summarise(n = sum(.data$number_records)) == 0)
   # We should have people in male cohorts
-  expect_true(CDMConnector::cohortCount(cdm$denominator) %>%
+  expect_true(omopgenerics::cohortCount(cdm$denominator) %>%
     dplyr::filter(cohort_definition_id %in% maleCohortIds) %>%
     dplyr::summarise(n = sum(.data$number_records)) > 0)
 
@@ -100,12 +100,12 @@ test_that("mock db: checks on working example", {
     ageGroup = list(c(50, 59), c(60, 69)),
     daysPriorObservation = c(0, 365)
   ))
-  expect_true(all(CDMConnector::cohortCount(cdm$denominator)$number_records == 0))
+  expect_true(all(omopgenerics::cohortCount(cdm$denominator)$number_records == 0))
   CDMConnector::cdm_disconnect(cdm)
 
   # using cohort target
   # add stratifying cohort
-  targetCohortTable <- tibble::tibble(
+  targetCohortTable <- dplyr::tibble(
     cohort_definition_id = 1,
     subject_id = c("1"),
     cohort_start_date = as.Date("2010-03-15"),
@@ -137,14 +137,14 @@ test_that("mock db: checks on working example", {
 test_that("mock db: check example we expect to work", {
   skip_on_cran()
   # one person, one observation periods
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 06,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = "1",
     person_id = "1",
     observation_period_start_date = as.Date("2010-01-01"),
@@ -157,7 +157,7 @@ test_that("mock db: check example we expect to work", {
   )
 
   cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
-  expect_true(CDMConnector::cohortCount(cdm$denominator)$number_records == 1)
+  expect_true(omopgenerics::cohortCount(cdm$denominator)$number_records == 1)
   expect_true(cdm$denominator %>%
     dplyr::collect() %>%
     dplyr::pull(cohort_start_date) == as.Date("2010-01-01"))
@@ -184,14 +184,14 @@ test_that("mock db: check example we expect to work", {
 test_that("mock db: check another example we expect to work", {
   skip_on_cran()
   # 5 person, 1 observation periods
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = c("1", "2", "3", "4", "5"),
     gender_concept_id = c("8507", "8532", "8507", "8532", "8532"),
     year_of_birth = c(1995, 1993, 1994, 1996, NA),
     month_of_birth = c(07, NA, 06, 05, 04),
     day_of_birth = c(25, NA, 01, 02, 03)
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1", "2", "3", "4", "5"),
     person_id = c("1", "2", "3", "4", "5"),
     observation_period_start_date = rep(as.Date("2000-01-01"), 5),
@@ -299,7 +299,7 @@ test_that("mock db: mock example 1000", {
     sex = c("Female", "Male", "Both"),
     daysPriorObservation = c(0, 30, 60, 90, 120, 150, 180)
   )
-  expect_true(any(CDMConnector::cohortCount(cdm$denominator)$number_records > 0))
+  expect_true(any(omopgenerics::cohortCount(cdm$denominator)$number_records > 0))
 
   # all options being used
   cdm <- generateDenominatorCohortSet(cdm, name = "denominator",
@@ -308,7 +308,7 @@ test_that("mock db: mock example 1000", {
     sex = c("Female", "Male", "Both"),
     daysPriorObservation = c(0, 180)
   )
-  expect_true(any(CDMConnector::cohortCount(cdm$denominator)$number_records > 0))
+  expect_true(any(omopgenerics::cohortCount(cdm$denominator)$number_records > 0))
   expect_true(min(cdm$denominator %>%
     dplyr::collect() %>%
     dplyr::pull(cohort_start_date)) >=
@@ -324,20 +324,20 @@ test_that("mock db: mock example 1000", {
 test_that("mock db: subset denominator by cohort", {
   skip_on_cran()
   # one person, one observation periods
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = c("1", "2", "3"),
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 06,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1", "2", "3"),
     person_id = c("1", "2", "3"),
     observation_period_start_date = as.Date("2010-01-01"),
     observation_period_end_date = as.Date("2015-06-01")
   )
-  targetCohortTable <- tibble::tibble(
+  targetCohortTable <- dplyr::tibble(
     cohort_definition_id = c(1, 1, 2),
     subject_id = c("1", "2", "2"),
     cohort_start_date = as.Date(c("2012-06-06", "2012-06-06", "2012-09-01")),
@@ -419,13 +419,13 @@ test_that("mock db: subset denominator by cohort", {
     targetCohortTable = "target",
     targetCohortId = c(1,2),
   )
-  expect_true(nrow(CDMConnector::settings(cdm$target_cohort_mult1))==2)
+  expect_true(nrow(omopgenerics::settings(cdm$target_cohort_mult1))==2)
   # without specifying target, should run for both
   cdm <- generateTargetDenominatorCohortSet(
     cdm = cdm, name = "target_cohort_mult2",
     targetCohortTable = "target"
   )
-  expect_true(nrow(CDMConnector::settings(cdm$target_cohort_mult2))==2)
+  expect_true(nrow(omopgenerics::settings(cdm$target_cohort_mult2))==2)
 
   expect_identical(cdm$target_cohort_mult1 %>%
                      dplyr::collect(),
@@ -433,7 +433,7 @@ test_that("mock db: subset denominator by cohort", {
                      dplyr::collect())
   CDMConnector::cdm_disconnect(cdm)
 
-  targetCohortTable <- tibble::tibble(
+  targetCohortTable <- dplyr::tibble(
     cohort_definition_id = c(1, 1, 2, 3,4,5,6,7,8,9,10,11,12),
     subject_id = c("1","2", "2", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1"),
     cohort_start_date = as.Date(c("2012-06-06", "2012-06-06", "2012-09-01", "2012-09-01",
@@ -452,12 +452,12 @@ test_that("mock db: subset denominator by cohort", {
     cdm = cdm, name = "target_cohort_mult1",
     targetCohortTable = "target",
   )
-  expect_true(nrow(CDMConnector::settings(cdm$target_cohort_mult1))==12)
+  expect_true(nrow(omopgenerics::settings(cdm$target_cohort_mult1))==12)
 
 
 
   # stratifying cohort multiple events per person
-  targetCohortTable <- tibble::tibble(
+  targetCohortTable <- dplyr::tibble(
     cohort_definition_id = "1",
     subject_id = c("1", "2", "2"),
     cohort_start_date = c(
@@ -512,14 +512,14 @@ test_that("mock db: subset denominator by cohort", {
 
   # multiple observation periods and multiple outcomes for a person
   # one person, one observation periods
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 06,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1", "2", "3"),
     person_id = c("1"),
     observation_period_start_date = c(
@@ -534,7 +534,7 @@ test_that("mock db: subset denominator by cohort", {
     )
   )
   # add stratifying cohort
-  targetCohortTable <- tibble::tibble(
+  targetCohortTable <- dplyr::tibble(
     cohort_definition_id = 1,
     subject_id = c("1", "1", "1"),
     cohort_start_date = c(
@@ -580,14 +580,14 @@ test_that("mock db: subset denominator by cohort", {
 
 test_that("mock db: one male, one female", {
   skip_on_cran()
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = c("1", "2"),
     gender_concept_id = c("8507", "8532"),
     year_of_birth = rep(2000, 2),
     month_of_birth = rep(01, 2),
     day_of_birth = rep(01, 2)
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1", "2"),
     person_id = c("1", "2"),
     observation_period_start_date = rep(as.Date("2010-01-01"), 2),
@@ -628,14 +628,14 @@ test_that("mock db: one male, one female", {
 test_that("mock db: check example with restriction on sex", {
 
   # two male, one female
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = c("1", "2", "3"),
     gender_concept_id = c("8507", "8507", "8532"),
     year_of_birth = rep(2000, 3),
     month_of_birth = rep(06, 3),
     day_of_birth = rep(01, 3)
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1", "2", "3"),
     person_id = c("1", "2", "3"),
     observation_period_start_date = rep(as.Date("2010-01-01"), 3),
@@ -659,20 +659,20 @@ test_that("mock db: check example with restriction on sex", {
     cdm = cdm, name = "denominator3",
     sex = "Female"
   )
-  expect_true(CDMConnector::cohortCount(cdm$denominator1)$number_records == 2)
-  expect_true(CDMConnector::cohortCount(cdm$denominator2)$number_records == 3)
-  expect_true(CDMConnector::cohortCount(cdm$denominator3)$number_records == 1)
+  expect_true(omopgenerics::cohortCount(cdm$denominator1)$number_records == 2)
+  expect_true(omopgenerics::cohortCount(cdm$denominator2)$number_records == 3)
+  expect_true(omopgenerics::cohortCount(cdm$denominator3)$number_records == 1)
   CDMConnector::cdm_disconnect(cdm)
 
   # one male only
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 06,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = "1",
     person_id = "1",
     observation_period_start_date = as.Date("2010-01-01"),
@@ -697,9 +697,9 @@ test_that("mock db: check example with restriction on sex", {
     cdm = cdm, name = "denominator3",
     sex = "Female"
   )
-  expect_true(CDMConnector::cohortCount(cdm$denominator1)$number_records == 1)
-  expect_true(CDMConnector::cohortCount(cdm$denominator2)$number_records == 1)
-  expect_true(CDMConnector::cohortCount(cdm$denominator3)$number_records == 0)
+  expect_true(omopgenerics::cohortCount(cdm$denominator1)$number_records == 1)
+  expect_true(omopgenerics::cohortCount(cdm$denominator2)$number_records == 1)
+  expect_true(omopgenerics::cohortCount(cdm$denominator3)$number_records == 0)
 
   CDMConnector::cdm_disconnect(cdm)
 })
@@ -707,14 +707,14 @@ test_that("mock db: check example with restriction on sex", {
 test_that("mock db: check example with restriction on age", {
 
   # three people, born in 2000, 2005, and 2010
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = c("1", "2", "3"),
     gender_concept_id = rep("8507", 3),
     year_of_birth = c(2000, 2005, 2010),
     month_of_birth = rep(06, 3),
     day_of_birth = rep(01, 3)
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1", "2", "3"),
     person_id = c("1", "2", "3"),
     observation_period_start_date = rep(as.Date("2010-01-01"), 3),
@@ -744,22 +744,22 @@ test_that("mock db: check example with restriction on age", {
     ageGroup = list(c(40, 150))
   ))
 
-  expect_true(CDMConnector::cohortCount(cdm$denominator_a)$number_records == 3)
-  expect_true(CDMConnector::cohortCount(cdm$denominator_b)$number_records == 2)
-  expect_true(CDMConnector::cohortCount(cdm$denominator_c)$number_records == 1)
-  expect_true(CDMConnector::cohortCount(cdm$denominator_d)$number_records == 0)
+  expect_true(omopgenerics::cohortCount(cdm$denominator_a)$number_records == 3)
+  expect_true(omopgenerics::cohortCount(cdm$denominator_b)$number_records == 2)
+  expect_true(omopgenerics::cohortCount(cdm$denominator_c)$number_records == 1)
+  expect_true(omopgenerics::cohortCount(cdm$denominator_d)$number_records == 0)
 
   CDMConnector::cdm_disconnect(cdm)
 
   # one person, born in 2000
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 06,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = "1",
     person_id = "1",
     observation_period_start_date = as.Date("2010-01-01"),
@@ -802,14 +802,14 @@ test_that("mock db: check age edge cases", {
 
   # same min and max
   # one person, born in 2000
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 06,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = "1",
     person_id = "1",
     observation_period_start_date = as.Date("2010-01-01"),
@@ -841,14 +841,14 @@ test_that("mock db: check age edge cases", {
 
 test_that("mock db check age target entry and exit", {
   skip_on_cran()
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 01,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = "1",
     person_id = "1",
     observation_period_start_date = as.Date("2008-01-01"),
@@ -893,20 +893,20 @@ test_that("mock db check age target entry and exit", {
 
 test_that("mock db check target prior observation requirement", {
   skip_on_cran()
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 01,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = "1",
     person_id = "1",
     observation_period_start_date = as.Date("2010-07-01"),
     observation_period_end_date = as.Date("2018-06-01")
   )
-  targetCohortTable <- tibble::tibble( # same as obs period
+  targetCohortTable <- dplyr::tibble( # same as obs period
     cohort_definition_id = 1,
     subject_id = "1",
     cohort_start_date = as.Date("2012-01-01"),
@@ -979,21 +979,21 @@ test_that("mock db: targetRequirementsAtEntry", {
   skip_on_cran()
 
   ## Prior observation
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = c("1","2"),
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 01,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1","2"),
     person_id =  c("1","2"),
     observation_period_start_date = c(as.Date("2012-01-01"),
                                       as.Date("2013-01-04")),
     observation_period_end_date = as.Date("2018-06-01")
   )
-  targetCohortTable <- tibble::tibble(
+  targetCohortTable <- dplyr::tibble(
     cohort_definition_id = 1,
     subject_id = c("1", "2"),
     cohort_start_date = c(as.Date("2012-01-05"),
@@ -1016,16 +1016,16 @@ test_that("mock db: targetRequirementsAtEntry", {
   )
   # enter when they satisfy prior hist reqs
   # subject 1 should be in both cohorts, subject 2 only in first with 0 day req
-  expect_true(CDMConnector::cohortCount(cdm$denom_reqs_any_time) %>%
+  expect_true(omopgenerics::cohortCount(cdm$denom_reqs_any_time) %>%
     dplyr::filter(cohort_definition_id == 1) %>%
     dplyr::pull("number_records") == 2)
-  expect_true(CDMConnector::cohortCount(cdm$denom_reqs_any_time) %>%
+  expect_true(omopgenerics::cohortCount(cdm$denom_reqs_any_time) %>%
                 dplyr::filter(cohort_definition_id == 2) %>%
                 dplyr::pull("number_records") == 1)
-  expect_true(CDMConnector::cohortCount(cdm$denom_reqs_any_time) %>%
+  expect_true(omopgenerics::cohortCount(cdm$denom_reqs_any_time) %>%
                 dplyr::filter(cohort_definition_id == 3) %>%
                 dplyr::pull("number_records") == 1)
-  expect_true(CDMConnector::cohortCount(cdm$denom_reqs_any_time) %>%
+  expect_true(omopgenerics::cohortCount(cdm$denom_reqs_any_time) %>%
                 dplyr::filter(cohort_definition_id == 4) %>%
                 dplyr::pull("number_records") == 0)
 
@@ -1040,20 +1040,20 @@ test_that("mock db: targetRequirementsAtEntry", {
 
 
   ## Age
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 02,
     day_of_birth = 02
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = "1",
     person_id = "1",
     observation_period_start_date = as.Date("2005-01-01"),
     observation_period_end_date = as.Date("2018-06-01")
   )
-  targetCohortTable <- tibble::tibble(
+  targetCohortTable <- dplyr::tibble(
     cohort_definition_id = 1,
     subject_id = c("1"),
     cohort_start_date = as.Date("2010-01-01"),
@@ -1087,11 +1087,11 @@ test_that("mock db: targetRequirementsAtEntry", {
   )
   # does enter
   # they satisfy age on cohort start date
-  expect_true(CDMConnector::cohortCount(cdm$denom_reqs_cohort_entry) %>%
+  expect_true(omopgenerics::cohortCount(cdm$denom_reqs_cohort_entry) %>%
                 dplyr::filter(cohort_definition_id == 1) %>%
                 dplyr::pull("number_records") == 1)
   # but they won´t contribute to the next age cohort
-  expect_true(CDMConnector::cohortCount(cdm$denom_reqs_cohort_entry) %>%
+  expect_true(omopgenerics::cohortCount(cdm$denom_reqs_cohort_entry) %>%
                 dplyr::filter(cohort_definition_id == 2) %>%
                 dplyr::pull("number_records") == 0)
 
@@ -1101,14 +1101,14 @@ test_that("mock db: targetRequirementsAtEntry", {
 test_that("mock db: check example with multiple observation periods", {
   skip_on_cran()
   # one person, two observation periods
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 06,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1", "2"),
     person_id = rep("1", 2),
     observation_period_start_date = c(
@@ -1129,8 +1129,8 @@ test_that("mock db: check example with multiple observation periods", {
   # one per observation period
   cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
   expect_true(nrow(cdm$denominator %>% dplyr::collect()) == 2)
-  expect_true(CDMConnector::cohortCount(cdm$denominator)$number_records == 2)
-  expect_true(CDMConnector::cohortCount(cdm$denominator)$number_subjects == 1)
+  expect_true(omopgenerics::cohortCount(cdm$denominator)$number_records == 2)
+  expect_true(omopgenerics::cohortCount(cdm$denominator)$number_subjects == 1)
 
   # expect one rows- if start date is 1st Jan 2011
   cdm <- generateDenominatorCohortSet(
@@ -1165,14 +1165,14 @@ test_that("mock db: check example with multiple observation periods", {
 test_that("mock db: check imputation of date of birth", {
   skip_on_cran()
   # one person with all info, one missing month, one missing day, and one both
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = c("1", "2", "3", "4"),
     gender_concept_id = rep("8507", 4),
     year_of_birth = rep(2000, 4),
     month_of_birth = c(03, NA, 03, NA),
     day_of_birth = c(03, 03, NA, NA)
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1", "2", "3", "4"),
     person_id = c("1", "2", "3", "4"),
     observation_period_start_date = rep(as.Date("2010-01-01"), 4),
@@ -1218,14 +1218,14 @@ test_that("mock db: check imputation of date of birth", {
 test_that("mock db: check edge cases (zero results expected)", {
   skip_on_cran()
   # one person, one observation periods
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 06,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = "1",
     person_id = "1",
     observation_period_start_date = as.Date("2010-01-01"),
@@ -1241,19 +1241,19 @@ test_that("mock db: check edge cases (zero results expected)", {
     cdm = cdm,name = "denominator",
     cohortDateRange = c(as.Date("2100-01-01"), as.Date(NA))
   ))
-  expect_true(CDMConnector::cohortCount(cdm$denominator)$number_records == 0)
+  expect_true(omopgenerics::cohortCount(cdm$denominator)$number_records == 0)
 
   expect_warning( cdm <- generateDenominatorCohortSet(
     cdm = cdm,name = "denominator",
     cohortDateRange = c(as.Date(NA), as.Date("1800-01-01"))
   ))
-  expect_true(CDMConnector::cohortCount(cdm$denominator)$number_records == 0)
+  expect_true(omopgenerics::cohortCount(cdm$denominator)$number_records == 0)
 
   expect_warning(cdm <- generateDenominatorCohortSet(
     cdm = cdm,name = "denominator",
     ageGroup = list(c(155, 200))
   ))
-  expect_true(CDMConnector::cohortCount(cdm$denominator)$number_records == 0)
+  expect_true(omopgenerics::cohortCount(cdm$denominator)$number_records == 0)
 
   # note could include people as it would go up to day before first birthday
   # but given observation period, here we would expect a null
@@ -1261,14 +1261,14 @@ test_that("mock db: check edge cases (zero results expected)", {
     cdm = cdm,name = "denominator",
     ageGroup = list(c(0, 1))
   ))
-  expect_true(CDMConnector::cohortCount(cdm$denominator)$number_records == 0)
+  expect_true(omopgenerics::cohortCount(cdm$denominator)$number_records == 0)
 
   expect_warning(cdm <- generateDenominatorCohortSet(
     cdm = cdm,name = "denominator",
     ageGroup = list(c(0, 15)),
     daysPriorObservation = 365000
   ))
-  expect_true(CDMConnector::cohortCount(cdm$denominator)$number_records == 0)
+  expect_true(omopgenerics::cohortCount(cdm$denominator)$number_records == 0)
 
   CDMConnector::cdm_disconnect(cdm)
 })
@@ -1337,7 +1337,7 @@ test_that("mock db: check expected errors", {
   ))
 
   # target table doesn´t conform
-  targetCohortTable <- tibble::tibble(
+  targetCohortTable <- dplyr::tibble(
     cohort_id = "1",
     id = c("1", "2"),
     start_date = as.Date("2012-06-06"),
@@ -1352,14 +1352,14 @@ test_that("mock db: check expected errors", {
 test_that("mock db: check attrition table logic", {
   skip_on_cran()
   # 7 person, 1 observation periods
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = c("1", "2", "3", "4", "5", "6", "7"),
     gender_concept_id = c("8507", "8532", "8507", "8532", "8532", "8507", NA),
     year_of_birth = c(1995, 1993, 1994, 1996, 1998, NA, 1993),
     month_of_birth = c(07, 02, 06, 05, 04, 10, 01),
     day_of_birth = c(25, 14, 01, 02, 03, 10, 12)
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1", "2", "3", "4", "5", "6", "7"),
     person_id = c("1", "2", "3", "4", "5", "6", "7"),
     observation_period_start_date = c(
@@ -1383,12 +1383,12 @@ test_that("mock db: check attrition table logic", {
 
   # check last n_current equals the number of rows of the denominator pop
   expect_true(nrow(cdm$denominator %>% dplyr::collect()) ==
-    CDMConnector::attrition(cdm$denominator)$number_records[7])
+    omopgenerics::attrition(cdm$denominator)$number_records[7])
 
   # check missings
   cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
-  expect_true(CDMConnector::attrition(cdm$denominator)$excluded_records[2] == 1)
-  expect_true(CDMConnector::attrition(cdm$denominator)$excluded_records[3] == 1)
+  expect_true(omopgenerics::attrition(cdm$denominator)$excluded_records[2] == 1)
+  expect_true(omopgenerics::attrition(cdm$denominator)$excluded_records[3] == 1)
 
   # check sex criteria
   cdm <- generateDenominatorCohortSet(
@@ -1396,8 +1396,8 @@ test_that("mock db: check attrition table logic", {
     sex = "Male"
   )
   expect_true(nrow(cdm$denominator %>% dplyr::collect()) ==
-    tail(CDMConnector::attrition(cdm$denominator)$number_records, 1))
-  expect_true(CDMConnector::attrition(cdm$denominator) %>%
+    tail(omopgenerics::attrition(cdm$denominator)$number_records, 1))
+  expect_true(omopgenerics::attrition(cdm$denominator) %>%
     dplyr::filter(reason == "Not Male") %>%
     dplyr::pull("excluded_records") == 3)
 
@@ -1406,8 +1406,8 @@ test_that("mock db: check attrition table logic", {
     sex = "Female"
   )
   expect_true(nrow(cdm$denominator %>% dplyr::collect()) ==
-    tail(CDMConnector::attrition(cdm$denominator)$number_records, 1))
-  expect_true(CDMConnector::attrition(cdm$denominator) %>%
+    tail(omopgenerics::attrition(cdm$denominator)$number_records, 1))
+  expect_true(omopgenerics::attrition(cdm$denominator) %>%
     dplyr::filter(reason == "Not Female") %>%
     dplyr::pull("excluded_records") == 2)
 
@@ -1416,14 +1416,14 @@ test_that("mock db: check attrition table logic", {
     cdm = cdm, name = "denominator",
     ageGroup = list(c(24, 25))
   )
-  expect_true(CDMConnector::attrition(cdm$denominator)$excluded_records[3] == 1)
+  expect_true(omopgenerics::attrition(cdm$denominator)$excluded_records[3] == 1)
 
   # check observation criteria
   cdm <- generateDenominatorCohortSet(
     cdm = cdm, name = "denominator",
     cohortDateRange = c(as.Date("2010-01-01"), as.Date("2012-01-01"))
   )
-  expect_true(CDMConnector::attrition(cdm$denominator)$excluded_records[5] == 2)
+  expect_true(omopgenerics::attrition(cdm$denominator)$excluded_records[5] == 2)
 
   # check prior observation criteria
   cdm <- generateDenominatorCohortSet(
@@ -1431,18 +1431,18 @@ test_that("mock db: check attrition table logic", {
     cohortDateRange = c(as.Date("2015-01-01"), as.Date("2016-06-30")),
     daysPriorObservation = 365
   )
-  expect_true(CDMConnector::attrition(cdm$denominator)$excluded_records[7] == 1)
+  expect_true(omopgenerics::attrition(cdm$denominator)$excluded_records[7] == 1)
   CDMConnector::cdm_disconnect(cdm)
 
   # multiple observation periods per person
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = "1",
     gender_concept_id = "8507",
     year_of_birth = 2000,
     month_of_birth = 06,
     day_of_birth = 01
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1", "2", "3"),
     person_id = c("1"),
     observation_period_start_date = c(
@@ -1463,9 +1463,9 @@ test_that("mock db: check attrition table logic", {
   )
   cdm <- generateDenominatorCohortSet(cdm = cdm, name = "denominator")
   expect_true(all(
-    CDMConnector::attrition(cdm$denominator)$number_records == 3))
+    omopgenerics::attrition(cdm$denominator)$number_records == 3))
   expect_true(all(
-    CDMConnector::attrition(cdm$denominator)$number_subjects == 1))
+    omopgenerics::attrition(cdm$denominator)$number_subjects == 1))
 
   CDMConnector::cdm_disconnect(cdm)
 })
@@ -1473,14 +1473,14 @@ test_that("mock db: check attrition table logic", {
 test_that("mock db: check attrition with multiple cohorts", {
   skip_on_cran()
 
-  personTable <- tibble::tibble(
+  personTable <- dplyr::tibble(
     person_id = c("1", "2"),
     gender_concept_id = c("8507", "8532"),
     year_of_birth = rep(2000, 2),
     month_of_birth = rep(01, 2),
     day_of_birth = rep(01, 2)
   )
-  observationPeriodTable <- tibble::tibble(
+  observationPeriodTable <- dplyr::tibble(
     observation_period_id = c("1", "2"),
     person_id = c("1", "2"),
     observation_period_start_date = c(as.Date("2000-01-01"), as.Date("2010-01-01")),
@@ -1497,46 +1497,46 @@ test_that("mock db: check attrition with multiple cohorts", {
   )
 
   # for male cohort we should have a row for those excluded for not being male
-  expect_true(any("Not Male" == CDMConnector::settings(cdm$denominator) %>%
+  expect_true(any("Not Male" == omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Male") %>%
-    dplyr::inner_join(CDMConnector::attrition(cdm$denominator),
+    dplyr::inner_join(omopgenerics::attrition(cdm$denominator),
       multiple = "all",
       by = "cohort_definition_id"
     ) %>%
     dplyr::pull(.data$reason)) == TRUE)
-  expect_true(any("Not Female" == CDMConnector::settings(cdm$denominator) %>%
+  expect_true(any("Not Female" == omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Male") %>%
-    dplyr::inner_join(CDMConnector::attrition(cdm$denominator),
+    dplyr::inner_join(omopgenerics::attrition(cdm$denominator),
       multiple = "all",
       by = "cohort_definition_id"
     ) %>%
     dplyr::pull(.data$reason)) == FALSE)
   # for female cohort we should have a row for those excluded for not being male
-  expect_true(any("Not Male" == CDMConnector::settings(cdm$denominator) %>%
+  expect_true(any("Not Male" == omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Female") %>%
-    dplyr::inner_join(CDMConnector::attrition(cdm$denominator),
+    dplyr::inner_join(omopgenerics::attrition(cdm$denominator),
       multiple = "all",
       by = "cohort_definition_id"
     ) %>%
     dplyr::pull(.data$reason)) == FALSE)
-  expect_true(any("Not Female" == CDMConnector::settings(cdm$denominator) %>%
+  expect_true(any("Not Female" == omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Female") %>%
-    dplyr::inner_join(CDMConnector::attrition(cdm$denominator),
+    dplyr::inner_join(omopgenerics::attrition(cdm$denominator),
       multiple = "all",
       by = "cohort_definition_id"
     ) %>%
     dplyr::pull(.data$reason)) == TRUE)
   # for both cohort we should have a row for those excluded for not being male
-  expect_true(any("Not Male" == CDMConnector::settings(cdm$denominator) %>%
+  expect_true(any("Not Male" == omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Both") %>%
-    dplyr::inner_join(CDMConnector::attrition(cdm$denominator),
+    dplyr::inner_join(omopgenerics::attrition(cdm$denominator),
       multiple = "all",
       by = "cohort_definition_id"
     ) %>%
     dplyr::pull(.data$reason)) == FALSE)
-  expect_true(any("Not Female" == CDMConnector::settings(cdm$denominator) %>%
+  expect_true(any("Not Female" == omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Both") %>%
-    dplyr::inner_join(CDMConnector::attrition(cdm$denominator),
+    dplyr::inner_join(omopgenerics::attrition(cdm$denominator),
       multiple = "all",
       by = "cohort_definition_id"
     ) %>%
@@ -1547,8 +1547,8 @@ test_that("mock db: check attrition with multiple cohorts", {
   )
 
   # nobody dropped for prior hist when req is 0
-  expect_true(CDMConnector::settings(cdm$denominator) %>%
-    dplyr::inner_join(CDMConnector::attrition(cdm$denominator),
+  expect_true(omopgenerics::settings(cdm$denominator) %>%
+    dplyr::inner_join(omopgenerics::attrition(cdm$denominator),
       multiple = "all",
       by = "cohort_definition_id"
     ) %>%
@@ -1556,8 +1556,8 @@ test_that("mock db: check attrition with multiple cohorts", {
     dplyr::filter(reason == "No observation time available after applying age, prior observation and, if applicable, target criteria") %>%
     dplyr::pull(.data$excluded_records) == 0)
   # some people dropped for prior hist when req is 1000
-  expect_true(CDMConnector::settings(cdm$denominator) %>%
-    dplyr::inner_join(CDMConnector::attrition(cdm$denominator),
+  expect_true(omopgenerics::settings(cdm$denominator) %>%
+    dplyr::inner_join(omopgenerics::attrition(cdm$denominator),
       multiple = "all",
       by = "cohort_definition_id"
     ) %>%
@@ -1587,7 +1587,7 @@ test_that("mock db: check tables were cleaned up", {
     ),
     daysPriorObservation = c(0, 1, 2)
   )
-  start_cohort_set <- CDMConnector::settings(cdm$my_denominator)
+  start_cohort_set <- omopgenerics::settings(cdm$my_denominator)
   endTables <- CDMConnector::listTables(attr(attr(cdm, "cdm_source"), "dbcon"),
                                         schema = attr(cdm, "write_schema")
   )
@@ -1610,12 +1610,12 @@ test_that("mock db: check tables were cleaned up", {
     cdm_schema = "main",
     write_schema = "main", cdm_name = "mock"
   )
-  expect_true(tibble::is_tibble(CDMConnector::settings(cdmReconn$my_denominator)))
-  expect_true(tibble::is_tibble(CDMConnector::cohortCount(cdmReconn$my_denominator)))
-  expect_true(tibble::is_tibble(CDMConnector::attrition(cdmReconn$my_denominator)))
+  expect_true(is.data.frame(omopgenerics::settings(cdmReconn$my_denominator)))
+  expect_true(is.data.frame(omopgenerics::cohortCount(cdmReconn$my_denominator)))
+  expect_true(is.data.frame(omopgenerics::attrition(cdmReconn$my_denominator)))
 
   expect_equal(start_cohort_set,
-               CDMConnector::settings(cdmReconn$my_denominator))
+               omopgenerics::settings(cdmReconn$my_denominator))
 
   CDMConnector::cdm_disconnect(cdm)
 })
@@ -1634,7 +1634,7 @@ test_that("mock db: requirement interactions", {
     daysPriorObservation = c(0, 30),
     requirementInteractions = TRUE
   )
-  expect_true(nrow(CDMConnector::settings(cdm$denominator)) == 4 * 3 * 2)
+  expect_true(nrow(omopgenerics::settings(cdm$denominator)) == 4 * 3 * 2)
 
   cdm <- generateDenominatorCohortSet(cdm,name = "denominator",
     ageGroup = list(
@@ -1645,36 +1645,36 @@ test_that("mock db: requirement interactions", {
     daysPriorObservation = c(0, 30),
     requirementInteractions = FALSE
   )
-  expect_true(nrow(CDMConnector::settings(cdm$denominator)) == 7)
+  expect_true(nrow(omopgenerics::settings(cdm$denominator)) == 7)
 
   # order matters
   # will use first value
-  nrow(CDMConnector::settings(cdm$denominator) %>%
+  nrow(omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Both") %>%
     dplyr::filter(age_group == "0 to 100") %>%
     dplyr::filter(days_prior_observation == 0)) == 1
 
-  nrow(CDMConnector::settings(cdm$denominator) %>%
+  nrow(omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Male") %>%
     dplyr::filter(age_group == "0 to 100") %>%
     dplyr::filter(days_prior_observation == 0)) == 1
 
-  nrow(CDMConnector::settings(cdm$denominator) %>%
+  nrow(omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Both") %>%
     dplyr::filter(age_group == "11 to 15") %>%
     dplyr::filter(days_prior_observation == 0)) == 1
-  nrow(CDMConnector::settings(cdm$denominator) %>%
+  nrow(omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Both") %>%
     dplyr::filter(age_group == "0 to 100") %>%
     dplyr::filter(days_prior_observation == 30)) == 1
 
 
-  nrow(CDMConnector::settings(cdm$denominator) %>%
+  nrow(omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Female") %>%
     dplyr::filter(age_group == "11 to 15") %>%
     dplyr::filter(days_prior_observation == 0)) == 0
 
-  nrow(CDMConnector::settings(cdm$denominator) %>%
+  nrow(omopgenerics::settings(cdm$denominator) %>%
     dplyr::filter(sex == "Male") %>%
     dplyr::filter(age_group == "0 to 100") %>%
     dplyr::filter(days_prior_observation == 30)) == 0
